# prometheus-connect

[![Codacy Badge](https://api.codacy.com/project/badge/Grade/48cebb81b5d34d7cb45bcc5f5e0d505b)](https://app.codacy.com/app/4n4nd/prometheus-connect?utm_source=github.com&utm_medium=referral&utm_content=4n4nd/prometheus-connect&utm_campaign=Badge_Grade_Settings)


A python wrapper for the prometheus http api
